@@ -16,10 +16,10 @@ import logging
 import sys
 from pathlib import Path
 
-from .tools.helper_functions import HelperFunctions as HF
-from .output.shared_structure import LBSNRecordDicts
-from .output.submit_data import LBSNTransfer
-from .input.load_data import LoadData
+from lbsntransform.tools.helper_functions import HelperFunctions as HF
+from lbsntransform.output.shared_structure import LBSNRecordDicts
+from lbsntransform.output.submit_data import LBSNTransfer
+from lbsntransform.input.load_data import LoadData
 
 
 class LBSNTransform():
@@ -59,7 +59,7 @@ class LBSNTransform():
             dbformat_output=None, dbuser_hllworker=None,
             dbserveraddress_hllworker=None, dbname_hllworker=None,
             dbpassword_hllworker=None, dbserverport_hllworker=None,
-            include_lbsn_bases=None):
+            include_lbsn_bases=None, dry_run=None, hmac_key=None):
         """Init settings for LBSNTransform"""
 
         # init logger level
@@ -70,7 +70,7 @@ class LBSNTransform():
             sys.stdout.detach(), sys.stdout.encoding, 'replace')
         sys.stdout.flush()
         self.log = HF.set_logger()
-
+        self.dry_run = dry_run
         # init global settings
 
         self.transfer_count = transfer_count
@@ -102,7 +102,8 @@ class LBSNTransform():
             SUPPRESS_LINEBREAKS=csv_suppress_linebreaks,
             dbformat_output=dbformat_output,
             hllworker_cursor=cursor_hllworker,
-            include_lbsn_bases=include_lbsn_bases)
+            include_lbsn_bases=include_lbsn_bases,
+            dry_run=self.dry_run)
         # load from local json/csv or from PostgresDB
         self.cursor_input = None
         self.is_local_input = is_local_input
@@ -112,10 +113,6 @@ class LBSNTransform():
                 dbname_input, dbpassword_input, dbserverport_input,
                 readonly=True, dict_cursor=True)
             self.cursor_input = cursor_input
-        #      loc_filelist = LoadData.read_local_files(config)
-        # else:
-        #      # establish input connection
-        #
 
         # initialize stats
         self.processed_total = 0
@@ -125,6 +122,10 @@ class LBSNTransform():
         # this is where all the converted data will be stored
         # note that one input record may contain many lbsn records
         self.lbsn_records = LBSNRecordDicts()
+        # prepare hmac
+        if self.output.dbformat_output == 'hll':
+            self.output.prepare_hmac(
+                hmac_key)
 
     def add_processed_records(self, lbsn_record):
         """Adds one or multiple LBSN Records (ProtoBuf)
@@ -151,7 +152,8 @@ class LBSNTransform():
     def store_lbsn_records(self):
         """Stores processed LBSN Records to chosen output format
         """
-        self.output.store_lbsn_record_dicts(self.lbsn_records)
+        self.output.store_lbsn_record_dicts(
+            self.lbsn_records)
         self.output.commit_changes()
         self.lbsn_records.clear()
 
